@@ -16,11 +16,13 @@ class Network:
     output layers.
     """
 
-    def __init__(self, rnn_layer: Union[RNNLayer, SRNNLayer], var_map: dict = None):
+    def __init__(self, n: int, rnn_layer: Union[RNNLayer, SRNNLayer], var_map: dict = None):
         """Instantiates network with a single RNN layer.
 
         Parameters
         ----------
+        n
+            Number of neurons in the RNN layer.
         rnn_layer
             `RNNLayer` instance.
         var_map
@@ -28,6 +30,7 @@ class Network:
             that contain the operator name as well.
         """
 
+        self.n = n
         self.rnn_layer = rnn_layer
         self.input_layer = None
         self.output_layer = None
@@ -37,10 +40,17 @@ class Network:
     def __getitem__(self, item: int):
         try:
             return self._model[item]
-        except AttributeError:
+        except TypeError:
             self.compile()
         return self._model[item]
 
+    def __len__(self):
+        try:
+            return len(self._model)
+        except TypeError:
+            self.compile()
+            return len(self._model)
+
     @classmethod
     def from_yaml(cls, node: Union[str, NodeTemplate], weights: np.ndarray, source_var: str, target_var: str,
                   input_var: str, output_var: str, spike_var: str = None, spike_def: str = None, op: str = None,
@@ -112,7 +122,7 @@ class Network:
                                             train_params=train_params, record_vars=record_vars, **kwargs)
 
         # initialize model
-        return cls(rnn_layer, var_map=new_vars)
+        return cls(weights.shape[0], rnn_layer, var_map=new_vars)
 
     @property
     def model(self) -> Sequential:
@@ -121,14 +131,12 @@ class Network:
         """
         return self._model
 
-    def add_input_layer(self, n: int, m: int, weights: np.ndarray = None, trainable: bool = False,
+    def add_input_layer(self, m: int, weights: np.ndarray = None, trainable: bool = False,
                         dtype: torch.dtype = torch.float64) -> InputLayer:
         """Add an input layer to the network. Networks can have either 1 or 0 input layers.
 
         Parameters
         ----------
-        n
-            Number of neurons in the RNN layer.
         m
             Number of input dimensions.
         weights
@@ -146,7 +154,7 @@ class Network:
         """
 
         # initialize input layer
-        input_layer = InputLayer(n, m, weights, trainable=trainable, dtype=dtype)
+        input_layer = InputLayer(self.n, m, weights, trainable=trainable, dtype=dtype)
 
         # add layer to model
         self.input_layer = input_layer
@@ -154,14 +162,12 @@ class Network:
         # return layer
         return self.input_layer
 
-    def add_output_layer(self, n: int, k: int, weights: np.ndarray = None, trainable: bool = False,
-                         activation_function: str = None, dtype: torch.dtype = torch.float64) -> OutputLayer:
+    def add_output_layer(self, k: int, weights: np.ndarray = None, trainable: bool = False,
+                         activation_function: str = None, dtype: torch.dtype = torch.float64, **kwargs) -> OutputLayer:
         """Add an output layer to the network. Networks can have either 1 or 0 output layers.
 
         Parameters
         ----------
-        n
-            Number of neurons in the RNN layer.
         k
             Number of output dimensions.
         weights
@@ -173,6 +179,8 @@ class Network:
             Optional activation function applied to the output of the output layer.
         dtype
             Data type of the input weights.
+        kwargs
+            Additional keyword arguments to be passed on to `rectipy.output_layer.OutputLayer`.
 
         Returns
         -------
@@ -181,8 +189,8 @@ class Network:
         """
 
         # initialize output layer
-        output_layer = OutputLayer(n, k, weights, trainable=trainable, activation_function=activation_function,
-                                   dtype=dtype)
+        output_layer = OutputLayer(self.n, k, weights, trainable=trainable, activation_function=activation_function,
+                                   dtype=dtype, **kwargs)
 
         # add layer to model
         self.output_layer = output_layer
@@ -607,6 +615,4 @@ class Network:
     def _get_layer(layer) -> tuple:
         if layer is None:
             return tuple()
-        if hasattr(layer, 'layer'):
-            return tuple([layer.layer])
         return tuple([layer])
